@@ -14,7 +14,7 @@ build = "797"
 
 sh = ['scribo']
 desktop_file = ['scribo.desktop']
-pixmaps = glob.glob('data/*.png')+ glob.glob('data/*.ico')
+pixmaps = glob.glob('data/*.png')+ glob.glob('data/*.ico')+glob.glob('data/ru/*.png')+glob.glob('data/en/*.png')
 srcs = glob.glob('src/*.py')+glob.glob('src/*.qm') 
 uisrcs =  glob.glob('src/ui/*.py') 
 bugsrcs =  glob.glob('src/bugz/*.py') 
