@@ -430,7 +430,10 @@ class Account(Structure):
 
         self.del_posts()
 
-        self._del_struct()
+        # FIXME: we cant delete structure because someone else can have this 
+        # account as a friend 
+        #self._del_struct()
+        self.prof = None
 
     def del_posts(self):
         """
@@ -438,11 +441,15 @@ class Account(Structure):
         
         @return None
         """
+        # FIXME: we cant delete posts because someone else can have this 
+        # account as a friend
+        '''
         query = 'SELECT id FROM Messages WHERE journal=? AND type=?'
         id_list = sql_driver.select_mcmd(query, (self._id, POST))
 
         for i in id_list:
             Message(i[0]).del_msg_tree()
+        '''
 
 
     def set_default(self):
