@@ -5,7 +5,7 @@
     <message>
         <location filename="AddPost.py" line="51"/>
         <source>Title</source>
-        <translation type="unfinished">Заголовок</translation>
+        <translation type="obsolete">Заголовок</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="53"/>
@@ -20,30 +20,30 @@
     <message>
         <location filename="AddPost.py" line="106"/>
         <source>&amp;Picture</source>
-        <translation type="unfinished">Рисунок</translation>
+        <translation type="obsolete">Рисунок</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="112"/>
         <source>&amp;Link</source>
-        <translation type="unfinished">Ссылка</translation>
+        <translation type="obsolete">Ссылка</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="118"/>
         <source>&amp;HTML</source>
-        <translation type="unfinished">HTML</translation>
+        <translation type="obsolete">HTML</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="124"/>
         <source>&amp;Option</source>
-        <translation type="unfinished">Опции</translation>
+        <translation type="obsolete">Опции</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="131"/>
         <source>&amp;Send</source>
-        <translation type="unfinished">Отправка</translation>
+        <translation type="obsolete">Отправка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="207"/>
+        <location filename="AddPost.py" line="422"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
@@ -63,29 +63,29 @@
         <translation type="obsolete">Пост изменен</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="225"/>
+        <location filename="AddPost.py" line="236"/>
         <source>Add picture</source>
         <translation type="unfinished">Добавить рисунок</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="226"/>
         <source>Type link on the picture in web</source>
-        <translation type="unfinished">Добавить ссылку на рисунок</translation>
+        <translation type="obsolete">Добавить ссылку на рисунок</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="407"/>
+        <location filename="AddPost.py" line="404"/>
         <source>Add</source>
         <translation type="unfinished">Добавить</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="252"/>
+        <location filename="AddPost.py" line="265"/>
         <source>Add link</source>
         <translation type="unfinished">Добавить ссылку</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="257"/>
         <source>Type link and address</source>
-        <translation type="unfinished">Ввести ссылку и адрес</translation>
+        <translation type="obsolete">Ввести ссылку и адрес</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="294"/>
@@ -93,90 +93,155 @@
         <translation type="obsolete">Добавить html теги</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="296"/>
+        <location filename="AddPost.py" line="306"/>
         <source>Bold</source>
         <translation type="unfinished">Жирный</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="300"/>
+        <location filename="AddPost.py" line="308"/>
         <source>Italic</source>
         <translation type="unfinished">Курсив</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="302"/>
+        <location filename="AddPost.py" line="310"/>
         <source>Center</source>
         <translation type="unfinished">По центру</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="304"/>
+        <location filename="AddPost.py" line="312"/>
         <source>Right</source>
         <translation type="unfinished">По правому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="306"/>
+        <location filename="AddPost.py" line="314"/>
         <source>Left</source>
         <translation type="unfinished">По левому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="308"/>
+        <location filename="AddPost.py" line="316"/>
         <source>Justify</source>
         <translation type="unfinished">По ширине</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="310"/>
+        <location filename="AddPost.py" line="318"/>
         <source>Color</source>
         <translation type="unfinished">Цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="363"/>
+        <location filename="AddPost.py" line="360"/>
         <source>Color text</source>
         <translation type="unfinished">Цветной текст</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="367"/>
+        <location filename="AddPost.py" line="363"/>
         <source>Choose color</source>
         <translation type="unfinished">Выбрать цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="396"/>
+        <location filename="AddPost.py" line="391"/>
         <source>Add option</source>
         <translation type="unfinished">Добавить опцию</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="404"/>
         <source>Comma separated tags</source>
-        <translation type="unfinished">Ввести теги через запятую</translation>
+        <translation type="obsolete">Ввести теги через запятую</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="53"/>
         <source>Text a new post</source>
-        <translation type="unfinished">Текст нового поста</translation>
+        <translation type="obsolete">Текст нового поста</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="61"/>
         <source>Text a editing post</source>
-        <translation type="unfinished">Редактируемый пост</translation>
+        <translation type="obsolete">Редактируемый пост</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="180"/>
         <source>Please, fill text of post!</source>
-        <translation type="unfinished">Пожалуйста, заполните поле с текстом</translation>
+        <translation type="obsolete">Пожалуйста, заполните поле с текстом</translation>
     </message>
     <message>
         <location filename="AddPost.py" line="186"/>
         <source>Do you want send post with empty title?</source>
-        <translation type="unfinished">Вы хотите отправить пост с пустым заголовком?</translation>
+        <translation type="obsolete">Вы хотите отправить пост с пустым заголовком?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="207"/>
+        <location filename="AddPost.py" line="220"/>
         <source>Post is edit</source>
         <translation type="unfinished">Пост редактирован</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="294"/>
+        <location filename="AddPost.py" line="303"/>
         <source>Add html tags</source>
         <translation type="unfinished">Добавить html теги</translation>
     </message>
+    <message>
+        <location filename="AddPost.py" line="52"/>
+        <source>Subject</source>
+        <translation type="unfinished">Тема</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="107"/>
+        <source>../data/en/image.png</source>
+        <translation type="unfinished">../data/ru/image_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="114"/>
+        <source>../data/en/add_link.png</source>
+        <translation type="unfinished">../data/ru/add_link_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="120"/>
+        <source>../data/en/add_html.png</source>
+        <translation type="unfinished">../data/en/add_html.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="126"/>
+        <source>../data/en/options.png</source>
+        <translation type="unfinished">../data/ru/options_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="135"/>
+        <source>../data/en/post_send_to.png</source>
+        <translation type="unfinished">../data/ru/post_send_to_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="139"/>
+        <source>../data/en/post_send.png</source>
+        <translation type="unfinished">../data/ru/post_send_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="193"/>
+        <source>The post is empty!</source>
+        <translation type="unfinished">Пост - пустой!!</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="200"/>
+        <source>Do you want to send post with empty subject?</source>
+        <translation type="unfinished">Вы действительно хотите послать пост без темы?</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="237"/>
+        <source>Link to the image (URL)</source>
+        <translation type="unfinished">Ссылка на изображение(URL)</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="269"/>
+        <source>Link</source>
+        <translation type="unfinished">Ссылка</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="401"/>
+        <source>Tags (comma separated)</source>
+        <translation type="unfinished">Теги (через запятую)</translation>
+    </message>
+    <message>
+        <location filename="AddPost.py" line="424"/>
+        <source>Post will be lost! Continue? </source>
+        <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
+    </message>
 </context>
 <context>
     <name>AddProfileWindow</name>
@@ -193,25 +258,25 @@
     <message>
         <location filename="AddProfile.py" line="63"/>
         <source>Service</source>
-        <translation type="unfinished">Сервис</translation>
+        <translation type="obsolete">Сервис</translation>
     </message>
     <message>
         <location filename="AddProfile.py" line="105"/>
         <source>&amp;Delete</source>
-        <translation type="unfinished">Удалить</translation>
+        <translation type="obsolete">Удалить</translation>
     </message>
     <message>
         <location filename="AddProfile.py" line="111"/>
         <source>&amp;OK</source>
-        <translation type="unfinished">Да</translation>
+        <translation type="obsolete">Да</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="240"/>
+        <location filename="AddProfile.py" line="242"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="178"/>
+        <location filename="AddProfile.py" line="181"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
@@ -221,55 +286,75 @@
         <translation type="obsolete">Вы действительно хотите удалить аккаунт?</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="240"/>
+        <location filename="AddProfile.py" line="243"/>
         <source>Account was deleted</source>
         <translation type="unfinished">Аккаунт удален</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="225"/>
+        <location filename="AddProfile.py" line="228"/>
         <source>Do you really want to delete account?</source>
         <translation type="unfinished">Вы действительно хотите удалить аккаунт?</translation>
     </message>
+    <message>
+        <location filename="AddProfile.py" line="63"/>
+        <source>Blog Service</source>
+        <translation type="unfinished">Блог сервис</translation>
+    </message>
+    <message>
+        <location filename="AddProfile.py" line="112"/>
+        <source>../data/en/remove_profile.png</source>
+        <translation type="unfinished">../data/ru/remove_profile_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddProfile.py" line="115"/>
+        <source>../data/en/change_profile_ok.png</source>
+        <translation type="unfinished">../data/ru/change_profile_ok_ru.png</translation>
+    </message>
+    <message>
+        <location filename="AddProfile.py" line="117"/>
+        <source>../data/en/add_profile.png</source>
+        <translation type="unfinished">../data/ru/add_profile_ru.png</translation>
+    </message>
 </context>
 <context>
     <name>HomePage</name>
     <message>
-        <location filename="HomePage.py" line="93"/>
+        <location filename="HomePage.py" line="94"/>
         <source>&lt;h2&gt;Personal info:&lt;/h2&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;h2&gt;Персональная информация:&lt;/h2&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="95"/>
+        <location filename="HomePage.py" line="96"/>
         <source>&lt;div&gt;Nick: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;Имя: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="99"/>
+        <location filename="HomePage.py" line="100"/>
         <source>&lt;/b&gt;&lt;/div&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;/b&gt;&lt;/div&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="98"/>
+        <location filename="HomePage.py" line="99"/>
         <source>&lt;div&gt;Birthday: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;День рождения: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="101"/>
+        <location filename="HomePage.py" line="102"/>
         <source>&lt;div&gt;City: &lt;b&gt;</source>
         <translation type="unfinished">&lt;div&gt;Город: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="102"/>
+        <location filename="HomePage.py" line="103"/>
         <source>&lt;/b&gt;&lt;/div&gt;</source>
         <translation type="unfinished">&lt;/b&gt;&lt;/div&gt;</translation>
     </message>
     <message>
         <location filename="HomePage.py" line="104"/>
         <source>&lt;div&gt;From service: &lt;b&gt;</source>
-        <translation type="unfinished">&lt;div&gt;Сервис: &lt;b&gt;</translation>
+        <translation type="obsolete">&lt;div&gt;Сервис: &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="HomePage.py" line="105"/>
+        <location filename="HomePage.py" line="106"/>
         <source>&lt;b&gt;&lt;br&gt;&lt;/div&gt;&lt;br&gt;</source>
         <translation type="unfinished">&lt;b&gt;&lt;br&gt;&lt;/div&gt;&lt;br&gt;</translation>
     </message>
@@ -291,7 +376,32 @@
     <message>
         <location filename="HomePage.py" line="172"/>
         <source>&amp;Friends posts</source>
-        <translation type="unfinished">Посты друзей</translation>
+        <translation type="obsolete">Посты друзей</translation>
+    </message>
+    <message>
+        <location filename="HomePage.py" line="105"/>
+        <source>&lt;div&gt;Blog service: &lt;b&gt;</source>
+        <translation type="unfinished">&lt;div&gt;Блог сервис: &lt;b&gt;</translation>
+    </message>
+    <message>
+        <location filename="HomePage.py" line="172"/>
+        <source>&amp;Friends&apos; posts</source>
+        <translation type="unfinished">&amp;Посты друзей</translation>
+    </message>
+    <message>
+        <location filename="HomePage.py" line="174"/>
+        <source>../data/en/add_post.png</source>
+        <translation type="unfinished">../data/en/add_post.png</translation>
+    </message>
+    <message>
+        <location filename="HomePage.py" line="175"/>
+        <source>../data/en/my_posts.png</source>
+        <translation type="unfinished">../data/en/my_posts.png</translation>
+    </message>
+    <message>
+        <location filename="HomePage.py" line="176"/>
+        <source>../data/en/friends_posts.png</source>
+        <translation type="unfinished">../data/en/friends_posts.png</translation>
     </message>
 </context>
 <context>
@@ -302,7 +412,7 @@
         <translation type="obsolete">Обновить</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="62"/>
+        <location filename="ListMyPosts.py" line="63"/>
         <source>Don&apos;t show this message again</source>
         <translation type="unfinished">Больше не показывать это сообщение</translation>
     </message>
@@ -312,32 +422,32 @@
         <translation type="obsolete">Нажмите кнопку для обновления постов</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="78"/>
+        <location filename="ListMyPosts.py" line="81"/>
         <source>no subject</source>
         <translation type="unfinished">без темы</translation>
     </message>
     <message>
         <location filename="ListMyPosts.py" line="120"/>
         <source>&amp;Refresh</source>
-        <translation type="unfinished">Обновить</translation>
+        <translation type="obsolete">Обновить</translation>
     </message>
     <message>
         <location filename="ListMyPosts.py" line="126"/>
         <source>&amp;Delete</source>
-        <translation type="unfinished">Удалить</translation>
+        <translation type="obsolete">Удалить</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="172"/>
+        <location filename="ListMyPosts.py" line="175"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="151"/>
+        <location filename="ListMyPosts.py" line="155"/>
         <source>Do you really want to delete post?</source>
         <translation type="unfinished">Вы действительно хотите удалить пост?</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="172"/>
+        <location filename="ListMyPosts.py" line="176"/>
         <source>Please, choose messages to delete!</source>
         <translation type="unfinished">Пожалуйста, выберите удаляемые сообщения</translation>
     </message>
@@ -347,7 +457,7 @@
         <translation type="obsolete">Подождите ...</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="185"/>
+        <location filename="ListMyPosts.py" line="189"/>
         <source>Cancel</source>
         <translation type="unfinished">Отмена</translation>
     </message>
@@ -357,30 +467,40 @@
         <translation type="obsolete">Получение данных ...</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="61"/>
+        <location filename="ListMyPosts.py" line="62"/>
         <source>Refresh message</source>
         <translation type="unfinished">Обновить сообщение</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="63"/>
+        <location filename="ListMyPosts.py" line="64"/>
         <source>Press &quot;Refresh&quot; to update post</source>
         <translation type="unfinished">Нажмите &quot;Обновить&quot; для обновления постов</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="185"/>
+        <location filename="ListMyPosts.py" line="188"/>
         <source>Operation is in progress.</source>
         <translation type="unfinished">Операция выполняется</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="187"/>
+        <location filename="ListMyPosts.py" line="190"/>
         <source>Receiving data...</source>
         <translation type="unfinished">Получение данных..</translation>
     </message>
+    <message>
+        <location filename="ListMyPosts.py" line="125"/>
+        <source>../data/en/refresh.png</source>
+        <translation type="unfinished">../data/ru/refresh_ru.png</translation>
+    </message>
+    <message>
+        <location filename="ListMyPosts.py" line="131"/>
+        <source>../data/en/post_delete.png</source>
+        <translation type="unfinished">../data/ru/post_delete_ru.png</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="MainWindow.py" line="103"/>
+        <location filename="MainWindow.py" line="102"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
@@ -395,17 +515,12 @@
         <translation type="obsolete">Редактирование аккаунтов</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="93"/>
+        <location filename="MainWindow.py" line="91"/>
         <source>About Scribo</source>
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="93"/>
-        <source>A mobile multiblog client. Version:</source>
-        <translation type="obsolete">Мобильный мультиблоговый клиент. Версия:</translation>
-    </message>
-    <message>
-        <location filename="MainWindow.py" line="116"/>
+        <location filename="MainWindow.py" line="113"/>
         <source>Ctrl+N</source>
         <translation type="unfinished">Ctrl+N</translation>
     </message>
@@ -415,28 +530,43 @@
         <translation type="obsolete">Выход</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="127"/>
+        <location filename="MainWindow.py" line="123"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished">Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="136"/>
+        <location filename="MainWindow.py" line="132"/>
         <source>&amp;About</source>
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="147"/>
+        <location filename="MainWindow.py" line="143"/>
         <source>&amp;Menu</source>
         <translation type="unfinished">Меню</translation>
     </message>
     <message>
         <location filename="MainWindow.py" line="49"/>
         <source>&amp;New Profile</source>
-        <translation type="unfinished">&amp;Новый аккаунт</translation>
+        <translation type="obsolete">&amp;Новый аккаунт</translation>
     </message>
     <message>
         <location filename="MainWindow.py" line="50"/>
         <source>&amp;Manage profile</source>
+        <translation type="obsolete">&amp;Редактирование аккаунтов</translation>
+    </message>
+    <message>
+        <location filename="MainWindow.py" line="122"/>
+        <source>E&amp;xit</source>
+        <translation type="unfinished">&amp;Выход</translation>
+    </message>
+    <message>
+        <location filename="MainWindow.py" line="49"/>
+        <source>&amp;New Account</source>
+        <translation type="unfinished">&amp;Новый аккаунт</translation>
+    </message>
+    <message>
+        <location filename="MainWindow.py" line="50"/>
+        <source>&amp;Edit Accounts</source>
         <translation type="unfinished">&amp;Редактирование аккаунтов</translation>
     </message>
     <message>
@@ -445,26 +575,21 @@
  Version: </source>
         <translation type="unfinished">Мобильный мультиблоговый клиент. Версия:</translation>
     </message>
-    <message>
-        <location filename="MainWindow.py" line="126"/>
-        <source>E&amp;xit</source>
-        <translation type="unfinished">&amp;Выход</translation>
-    </message>
 </context>
 <context>
     <name>MyModel</name>
     <message>
-        <location filename="TreeMessage.py" line="116"/>
+        <location filename="TreeMessage.py" line="117"/>
         <source>Author</source>
         <translation type="unfinished">Автор</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="117"/>
+        <location filename="TreeMessage.py" line="118"/>
         <source>Date</source>
         <translation type="unfinished">Дата</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="118"/>
+        <location filename="TreeMessage.py" line="119"/>
         <source>Title</source>
         <translation type="unfinished">Заголовок</translation>
     </message>
@@ -474,43 +599,53 @@
     <message>
         <location filename="RepeatPost.py" line="40"/>
         <source>Please, choose accounts and groups for sending the post</source>
-        <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки поста</translation>
+        <translation type="obsolete">Пожалуйста, выберите аккаунты или группы для отправки поста</translation>
     </message>
     <message>
         <location filename="RepeatPost.py" line="58"/>
         <source>&amp;Send</source>
-        <translation type="unfinished">Отправить</translation>
+        <translation type="obsolete">Отправить</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="66"/>
+        <location filename="RepeatPost.py" line="67"/>
         <source>Service</source>
         <translation type="unfinished">Сервис</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="67"/>
+        <location filename="RepeatPost.py" line="68"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="168"/>
+        <location filename="RepeatPost.py" line="171"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="141"/>
+        <location filename="RepeatPost.py" line="144"/>
         <source>Please, choose subitem for sending</source>
         <translation type="unfinished">Пожалуйста, выберите подпункт для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="162"/>
+        <location filename="RepeatPost.py" line="165"/>
         <source>Please, choose accounts or groups for sending</source>
         <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="168"/>
+        <location filename="RepeatPost.py" line="172"/>
         <source>Post was sent</source>
         <translation type="unfinished">Пост отправлен</translation>
     </message>
+    <message>
+        <location filename="RepeatPost.py" line="40"/>
+        <source>Select accounts and groups for sending</source>
+        <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки</translation>
+    </message>
+    <message>
+        <location filename="RepeatPost.py" line="60"/>
+        <source>../data/en/send_post.png</source>
+        <translation type="unfinished">../data/ru/send_post_ru.png</translation>
+    </message>
 </context>
 <context>
     <name>StartPage</name>
@@ -527,7 +662,7 @@
     <message>
         <location filename="StartPage.py" line="46"/>
         <source>Service</source>
-        <translation type="unfinished">Сервис</translation>
+        <translation type="obsolete">Сервис</translation>
     </message>
     <message>
         <location filename="StartPage.py" line="59"/>
@@ -540,32 +675,52 @@
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="StartPage.py" line="100"/>
+        <location filename="StartPage.py" line="101"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
     <message>
         <location filename="StartPage.py" line="162"/>
         <source>&lt;i&gt;Welcome to Scribo!&lt;/i&gt;</source>
-        <translation type="unfinished">Добро пожаловать в Scribo!</translation>
+        <translation type="obsolete">Добро пожаловать в Scribo!</translation>
     </message>
     <message>
         <location filename="StartPage.py" line="164"/>
         <source>../data/Scribo.png</source>
         <translation type="unfinished">../data/Scribo.png</translation>
     </message>
+    <message>
+        <location filename="StartPage.py" line="46"/>
+        <source>Blog service</source>
+        <translation type="unfinished">Блог сервис</translation>
+    </message>
+    <message>
+        <location filename="StartPage.py" line="162"/>
+        <source>&lt;i&gt;Welcome to Scribo,&lt;br/&gt; mobile multiblog client!&lt;/i&gt;</source>
+        <translation type="unfinished">&lt;i&gt;Добро пожаловать в Скрибо,&lt;br/&gt;мобильный мультиблоговый&lt;br/&gt; клиент!&lt;/i&gt;</translation>
+    </message>
 </context>
 <context>
     <name>ToolbarWindow</name>
     <message>
         <location filename="ToolbarWindow.py" line="27"/>
         <source>&amp;Back</source>
-        <translation type="unfinished">&amp;Назад</translation>
+        <translation type="obsolete">&amp;Назад</translation>
     </message>
     <message>
         <location filename="ToolbarWindow.py" line="33"/>
         <source>&amp;Home</source>
-        <translation type="unfinished">&amp;Домой</translation>
+        <translation type="obsolete">&amp;Домой</translation>
+    </message>
+    <message>
+        <location filename="ToolbarWindow.py" line="29"/>
+        <source>../data/en/back.png</source>
+        <translation type="obsolete">../data/ru/back_ru.png</translation>
+    </message>
+    <message>
+        <location filename="ToolbarWindow.py" line="35"/>
+        <source>../data/en/home.png</source>
+        <translation type="obsolete">../data/ru/home_ru.png</translation>
     </message>
 </context>
 <context>
@@ -573,13 +728,18 @@
     <message>
         <location filename="TreeMessage.py" line="73"/>
         <source>&amp;Refresh</source>
-        <translation type="unfinished">&amp;Обновить</translation>
+        <translation type="obsolete">&amp;Обновить</translation>
+    </message>
+    <message>
+        <location filename="TreeMessage.py" line="76"/>
+        <source>../data/en/refresh.png</source>
+        <translation type="unfinished">../data/ru/refresh_ru.png</translation>
     </message>
 </context>
 <context>
     <name>ViewMessage</name>
     <message>
-        <location filename="ViewMessage.py" line="87"/>
+        <location filename="ViewMessage.py" line="103"/>
         <source>no subject</source>
         <translation type="unfinished">без темы</translation>
     </message>
@@ -611,17 +771,17 @@
     <message>
         <location filename="ViewMessage.py" line="196"/>
         <source>&amp;Previous</source>
-        <translation type="unfinished">Предыдущее</translation>
+        <translation type="obsolete">Предыдущее</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="202"/>
         <source>&amp;Next</source>
-        <translation type="unfinished">Следующее</translation>
+        <translation type="obsolete">Следующее</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="215"/>
         <source>&amp;Edit</source>
-        <translation type="unfinished">Редактировать</translation>
+        <translation type="obsolete">Редактировать</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="221"/>
@@ -631,34 +791,62 @@
     <message>
         <location filename="ViewMessage.py" line="121"/>
         <source>Post:&lt;/font&gt; &lt;/h3&gt;&lt;b&gt;Title: &lt;/b&gt;</source>
-        <translation type="unfinished">Пост:&lt;/font&gt; &lt;/h3&gt;&lt;b&gt;Заголовок: &lt;/b&gt;</translation>
+        <translation type="obsolete">Пост:&lt;/font&gt; &lt;/h3&gt;&lt;b&gt;Заголовок: &lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="121"/>
         <source>&lt;br/&gt; &lt;b&gt; Author: &lt;/b&gt;</source>
-        <translation type="unfinished">&lt;br/&gt; &lt;b&gt; Автор: &lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;br/&gt; &lt;b&gt; Автор: &lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="121"/>
         <source>&lt;br/&gt;&lt;b&gt; Date: &lt;/b&gt;</source>
-        <translation type="unfinished">&lt;br/&gt;&lt;b&gt; Дата: &lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;br/&gt;&lt;b&gt; Дата: &lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="121"/>
         <source>&lt;br/&gt;&lt;b&gt; Tags: &lt;/b&gt;</source>
-        <translation type="unfinished">&lt;br/&gt;&lt;b&gt; Теги: &lt;/b&gt;</translation>
+        <translation type="obsolete">&lt;br/&gt;&lt;b&gt; Теги: &lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="ViewMessage.py" line="121"/>
         <source>&lt;br/&gt;&lt;b&gt; Text:
                     &lt;/b&gt;&lt;br /&gt;&lt;/div&gt;</source>
-        <translation type="unfinished">&lt;br/&gt;&lt;b&gt; Текст:
+        <translation type="obsolete">&lt;br/&gt;&lt;b&gt; Текст:
                     &lt;/b&gt;&lt;br /&gt;&lt;/div&gt;</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="221"/>
+        <location filename="ViewMessage.py" line="232"/>
         <source>&amp;Tree comments</source>
         <translation type="unfinished">&amp;Дерево комментариев</translation>
     </message>
+    <message>
+        <location filename="ViewMessage.py" line="209"/>
+        <source>../data/en/post_prev.png</source>
+        <translation type="unfinished">../data/ru/post_prev_ru.png</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="215"/>
+        <source>../data/en/post_next.png</source>
+        <translation type="unfinished">../data/ru/post_next_ru.png</translation>
+    </message>
+    <message>
+        <location filename="ViewMessage.py" line="228"/>
+        <source>../data/en/post_edit.png</source>
+        <translation type="unfinished">../data/ru/post_edit_ru.png</translation>
+    </message>
+</context>
+<context>
+    <name>main_window</name>
+    <message>
+        <location filename="ToolbarWindow.py" line="29"/>
+        <source>../data/en/back.png</source>
+        <translation type="unfinished">../data/ru/back_ru.png</translation>
+    </message>
+    <message>
+        <location filename="ToolbarWindow.py" line="35"/>
+        <source>../data/en/home.png</source>
+        <translation type="unfinished">../data/ru/home_ru.png</translation>
+    </message>
 </context>
 </TS>
