@@ -51,16 +51,13 @@ class AddPostWindow(ToolbarWindow):
 
         title_label = QtGui.QLabel(self.tr("Subject"), self)
         title_label.setAlignment(QtCore.Qt.AlignLeft)
-        #text_label = QtGui.QLabel(self.tr("Text a new post"), self)
-        #text_label.setAlignment(QtCore.Qt.AlignLeft)
-
+        
         self.text_edit = QtGui.QTextEdit(self)
         self.title_edit = QtGui.QLineEdit(self)
         self.title_edit.setMaxLength(100)
         if msg:
             self.text_edit.insertPlainText(msg.text)
             self.start_text = msg.text
-            #text_label.setText(self.tr("Text a editing post"))
             title = msg.title
             if not msg.title:
                 title = ""
@@ -71,7 +68,6 @@ class AddPostWindow(ToolbarWindow):
         self.hbox_all.addSpacing(5)
         self.vbox_add.addWidget(title_label)
         self.vbox_add.addWidget(self.title_edit)
-        #self.vbox_add.addWidget(text_label)
         self.vbox_add.addWidget(self.text_edit)
 
         self.hbox_all.addLayout(self.vbox_add)
@@ -107,40 +103,40 @@ class AddPostWindow(ToolbarWindow):
         @return
         """
 
-        self.pict_act = QtGui.QAction(self.tr("&Add image"), self)
-        self.pict_act.setIcon(QtGui.QIcon("../data/picture.png"))
-        self.pict_act.setIconText(self.tr("Add image"))
-        #self.pict_act.setToolTip(self.tr("Add Picture"))
-        #self.pict_act.setText(self.tr("Add Picture"))
+        self.pict_act = QtGui.QAction(self)
+        self.pict_act.setIcon(QtGui.QIcon(self.tr("../data/en/image.png")))
+        #self.pict_act.setIconText(self.tr("Add image"))
         self.connect(self.pict_act, QtCore.SIGNAL("triggered()"),
                      self.pict_post)
 
-        self.link_act = QtGui.QAction(self.tr("&Add URL"), self)
+        self.link_act = QtGui.QAction(self)
         #self.link_act.setStatusTip(self.tr("Add link"))
-        self.link_act.setIcon(QtGui.QIcon("../data/link.png"))
+        self.link_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_link.png")))
         self.connect(self.link_act, QtCore.SIGNAL("triggered()"),
                      self.link_post)
 
-        self.other_act = QtGui.QAction(self.tr("&HTML tags"), self)
+        self.other_act = QtGui.QAction(self)
         #self.other_act.setStatusTip(self.tr("Other HTML tags"))
-        self.other_act.setIcon(QtGui.QIcon("../data/add.png"))
+        self.other_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_html.png")))
         self.connect(self.other_act, QtCore.SIGNAL("triggered()"),
                      self.other_post)
 
-        self.option_act = QtGui.QAction(self.tr("&Specials"), self)
+        self.option_act = QtGui.QAction(self)
         #self.option_act.setStatusTip(self.tr("Adding option"))
-        self.option_act.setIcon(QtGui.QIcon("../data/property.png"))
+        self.option_act.setIcon(QtGui.QIcon(self.tr("../data/en/options.png")))
         self.connect(self.option_act, QtCore.SIGNAL("triggered()"),
                      self.option_post)
 
 
-        self.send_act = QtGui.QAction(self.tr("&Send to.."), self)
+        self.send_act = QtGui.QAction(self)
         #self.send_act.setStatusTip(self.tr("Send post"))
-        self.send_act.setIcon(QtGui.QIcon("../data/ok.png"))
+        
         if not self.msg:
+            self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_send_to.png")))
             self.connect(self.send_act, QtCore.SIGNAL("triggered()"),
                          self.send_post)
         else:
+            self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_send.png")))
             self.connect(self.send_act, QtCore.SIGNAL("triggered()"),
                          self.edit_post)
 
@@ -237,9 +233,6 @@ class AddPostWindow(ToolbarWindow):
 
         msg = QtGui.QMessageBox()
         uri_edit = QtGui.QLineEdit(msg)
-        #msg.layout().setSizeConstraint(QtGui.QLayout.SetMaximumSize)
-        #uri_edit.setSizeIncrement(100, 100)
-        #uri_edit.setText("http://")
         msg.setWindowTitle(self.tr("Add picture"))
         title_label = QtGui.QLabel(self.tr("Link to the image (URL)"), msg)
         msg.layout().addWidget(title_label, 0, 0)
@@ -309,10 +302,9 @@ class AddPostWindow(ToolbarWindow):
 
         self.dial.setWindowTitle(self.tr("Add html tags"))
         self.dial.setOrientation(QtCore.Qt.Horizontal)
+
         self.bold_button = but_box.addButton(self.tr("Bold"),
                                      QtGui.QDialogButtonBox.ActionRole)
-        #self.bold_button.setIcon(QtGui.QIcon("../data/bold.png"))        
-
         self.italic_button = but_box.addButton(self.tr("Italic"),
                                        QtGui.QDialogButtonBox.ActionRole)
         self.center_button = but_box2.addButton(self.tr("Center"),
@@ -338,40 +330,30 @@ class AddPostWindow(ToolbarWindow):
 
         self.dial.exec_()
         if self.dial.clickedButton() == QtGui.QMessageBox.Abort:
-            print "abort"
+            pass
         else:
-            print "reject"
             return
-
-
-
+    
     def html_click(self, button):
         text = ""
 
         if button == self.bold_button:
-            print "bold"
             self.text_edit.insertPlainText("<b>" + text + "</b>")
         elif button == self.italic_button:
-            print "ital"
             self.text_edit.insertPlainText("<i>" + text + "</i>")
         elif button == self.center_button:
-            print "center"
             self.text_edit.insertPlainText("<div style=\"text-align:center\">"
                                       + text + "</div>")
         elif button == self.right_button:
-            print "right"
             self.text_edit.insertPlainText("<div style=\"text-align:right\">"
                                       + text + "</div>")
         elif button == self.left_button:
-            print "left"
             self.text_edit.insertPlainText("<div style=\"text-align:left\">"
                                       + text + "</div>")
         elif button == self.just_button:
-            print "just"
             self.text_edit.insertPlainText("<div style=\"text-align:justify\">"
                                       + text + "</div>")
         elif button == self.color_button:
-            print "colrr"
             color_edit = QtGui.QLineEdit()
 
             msg2 = QtGui.QMessageBox()
@@ -390,12 +372,11 @@ class AddPostWindow(ToolbarWindow):
                     green = QtCore.QString().number(col.green(), 16).toUpper()
                     blue = QtCore.QString().number(col.blue(), 16).toUpper()
                     color = red + green + blue
-        	    self.text_edit.insertPlainText("<font color=\"#"
+                    self.text_edit.insertPlainText("<font color=\"#"
                                                + color + "\">"
                                                + link + "</font>")
         else:
-    	    print "else"
-            return
+    	    return
         self.dial.reject()
 
 
@@ -428,8 +409,7 @@ class AddPostWindow(ToolbarWindow):
         if msg.clickedButton() == cancel_button:
             return
         if msg.clickedButton() == link_button:
-	    print "tags"
-            self.tags = tag_edit.toPlainText()
+	        self.tags = tag_edit.toPlainText()
             #self.text_edit.deselect()
 
     def text_changed(self):
