@@ -120,7 +120,7 @@ class HomePage(QtGui.QWidget):
             self.upic = QtGui.QImage(path_ava)
             self.image_label.setPixmap(QtGui.QPixmap.fromImage(self.upic))
         else:
-             self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/user.png")))
+             self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/en/no_photo_128.png")))
 
 
 
@@ -149,7 +149,7 @@ class HomePage(QtGui.QWidget):
             self.upic = QtGui.QImage(path_ava)
             self.image_label.setPixmap(QtGui.QPixmap.fromImage(self.upic))
         else:
-            self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/user.png")))
+            self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/en/no_photo_128.png")))
 
         vbox1.addWidget(self.image_label)
         vbox1.addWidget(self.acc_combo_box)
@@ -171,9 +171,9 @@ class HomePage(QtGui.QWidget):
         my_post_button = QtGui.QPushButton(self.tr("&My posts"), self)
         friends_posts_btn = QtGui.QPushButton(self.tr("&Friends' posts"), self)
 
-        add_post_button.setIcon(QtGui.QIcon("../data/add_post.png"))
-        my_post_button.setIcon(QtGui.QIcon("../data/tree2.png"))
-        friends_posts_btn.setIcon(QtGui.QIcon("../data/tree2.png"))
+        add_post_button.setIcon(QtGui.QIcon(self.tr("../data/en/add_post.png")))
+        my_post_button.setIcon(QtGui.QIcon(self.tr("../data/en/my_posts.png")))
+        friends_posts_btn.setIcon(QtGui.QIcon(self.tr("../data/en/friends_posts.png")))
 
         hbox = QtGui.QHBoxLayout()
         hbox.addWidget(add_post_button, -1, QtCore.Qt.AlignCenter)
