@@ -51,7 +51,7 @@ class ListMyPosts(ToolbarWindow):
         """
         list_widget = QtGui.QListWidget(self)
         self.list = self.get_messages()
-        upic = QtGui.QImage("../data/faviconLJ.ico")
+        #upic = QtGui.QImage("../data/faviconLJ.ico")
         index = 0
 
         if len(self.list) == 0:
@@ -70,14 +70,10 @@ class ListMyPosts(ToolbarWindow):
                 if msg.clickedButton() == cancel_button:
                     if show_button.isChecked():
                         config.set('UI', 'warning_press_refresh', True)
-                        print "Checked"
-
+                        
 
         for mes in self.list:
-            #date = unicode(mes.date)
             date = mes.date
-            #datetime = QtCore.QDateTime().fromString(date, "YYYY-MM-DD hh:mm:ss")
-            #date = datetime.toString(QtCore.Qt.DefaultLocaleShortDate)
             import time
             datetime = time.strptime(date, "%Y-%m-%d %H:%M:%S")
             date = time.strftime("%a, %d %b %Y %H:%M", datetime)
@@ -124,15 +120,15 @@ class ListMyPosts(ToolbarWindow):
         create buttons for toolbar
         @return
         """
-        self.refresh_act = QtGui.QAction(self.tr("&Refresh"), self)
+        self.refresh_act = QtGui.QAction(self)
         #self.refresh_act.setStatusTip(self.tr("Refresh"))
-        self.refresh_act.setIcon(QtGui.QIcon("../data/refresh.png"))
+        self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
         self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
                      self.reload_window)
 
-        self.del_act = QtGui.QAction(self.tr("&Delete"), self)
+        self.del_act = QtGui.QAction(self)
         #self.del_act.setStatusTip(self.tr("Delete"))
-        self.del_act.setIcon(QtGui.QIcon("../data/del.png"))
+        self.del_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_delete.png")))
         self.connect(self.del_act, QtCore.SIGNAL("triggered()"),
                      self.delete_message)
 
