@@ -87,9 +87,7 @@ class MainWindow(QtGui.QMainWindow):
         @param 
         @return
         """
-        #from ConfigDriver import config
         from About import __version__ as ver
-        #ver = 
         QtGui.QMessageBox.about(self, self.tr("About Scribo"),
                                 self.tr("A mobile multiblog client."\
                                         " \n Version: " + ver))
@@ -112,13 +110,11 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
-        #self.new_act = QtGui.QAction(self.tr("&New Profile"), self)
         self.new_act.setShortcut(self.tr("Ctrl+N"))
         #self.new_act.setStatusTip(self.tr("Create a new profile"))
         self.connect(self.new_act, QtCore.SIGNAL("triggered()"),
                      self.new_profile)
 
-        #self.manage_act = QtGui.QAction(self.tr("&Manage profile"), self)
         #self.manage_act.setStatusTip(self.tr("Manage existing profile"))
         self.connect(self.manage_act, QtCore.SIGNAL("triggered()"),
                      self.manage_profile)
@@ -178,7 +174,6 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
-        print "back"
         widg = self.stack_widg.currentWidget()
         self.stack_widg.removeWidget(widg)
         widg.deleteLater()
@@ -190,7 +185,6 @@ class MainWindow(QtGui.QMainWindow):
         @param
         @return
         """
-        print "go home"
         count = self.stack_widg.count()
 
         for _ in xrange(count):
