@@ -43,7 +43,7 @@ class RepeatPost(ToolbarWindow):
         self.vbox = QtGui.QVBoxLayout()
         self.hbox = QtGui.QHBoxLayout()
         self.hbox.addWidget(toolbar)
-        self.hbox.addStretch(10)
+        self.hbox.addSpacing(10)
         self.vbox.addWidget(title)
         self.vbox.addWidget(self.tree_view)
         self.hbox.addLayout(self.vbox)
@@ -56,8 +56,8 @@ class RepeatPost(ToolbarWindow):
         @return
         """
         file_tool_bar = super(RepeatPost, self).create_toolbar()
-        self.send_act = QtGui.QAction(self.tr("&Send"), self)
-        self.send_act.setIcon(QtGui.QIcon("../data/ok.png"))
+        self.send_act = QtGui.QAction(self)
+        self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/send_post.png")))
         self.connect(self.send_act, QtCore.SIGNAL("triggered()"), self.send_selected)
         file_tool_bar.addAction(self.send_act)
         return file_tool_bar
