@@ -57,7 +57,7 @@ class StartPage(QtGui.QWidget):
         self.serv_combo = self.fill_combo()
 
         start_button = QtGui.QPushButton(self.tr("Go"), self)
-        start_button.setIcon(QtGui.QIcon("../data/key.png"))
+        #start_button.setIcon(QtGui.QIcon("../data/key.png"))
         self.connect(start_button, QtCore.SIGNAL("clicked()"), self.add_account)
 
         grid = QtGui.QGridLayout()
@@ -159,7 +159,7 @@ class StartPage(QtGui.QWidget):
         vbox2 = QtGui.QVBoxLayout()
         image_label = QtGui.QLabel(self)
         image_label.setAlignment(QtCore.Qt.AlignCenter)
-        start_label = QtGui.QLabel(self.tr("<i>Welcome to Scribo,</br> mobile multiblog client!</i>"), self)
+        start_label = QtGui.QLabel(self.tr("<i>Welcome to Scribo,<br/> mobile multiblog client!</i>"), self)
         start_label.setAlignment(QtCore.Qt.AlignCenter)
         upic = QtGui.QImage(self.tr("../data/Scribo.png"))
         image_label.setPixmap(QtGui.QPixmap.fromImage(upic))
