@@ -24,15 +24,15 @@ class ToolbarWindow(QtGui.QWidget):
         create buttons for toolbar
         @return
         """
-        self.back_act = QtGui.QAction(self.tr("&Back"), self)
+        self.back_act = QtGui.QAction(self)
         #self.back_act.setStatusTip(self.tr("On previous page"))
-        self.back_act.setIcon(QtGui.QIcon("../data/back.png"))
+        self.back_act.setIcon(QtGui.QIcon(main_window.tr('../data/en/back.png')))
         self.connect(self.back_act, QtCore.SIGNAL("triggered()"),
                      main_window.back_window)
 
-        self.home_act = QtGui.QAction(self.tr("&Home"), self)
+        self.home_act = QtGui.QAction(self)
         #self.home_act.setStatusTip(self.tr("Home page"))
-        self.home_act.setIcon(QtGui.QIcon("../data/home.png"))
+        self.home_act.setIcon(QtGui.QIcon(main_window.tr('../data/en/home.png')))
         self.connect(self.home_act, QtCore.SIGNAL("triggered()"),
                      main_window.home_window)
 
@@ -41,7 +41,9 @@ class ToolbarWindow(QtGui.QWidget):
         create profile for "add profile" window
         @return
         """
-        file_tool_bar = QtGui.QToolBar("", self)
+        #file_tool_bar = QtGui.QToolBar("", self)
+        centr_widg = main_window.centralWidget()
+        file_tool_bar = QtGui.QToolBar(centr_widg)
         file_tool_bar.setOrientation(QtCore.Qt.Vertical)
         file_tool_bar.setAllowedAreas(QtCore.Qt.LeftToolBarArea)
         file_tool_bar.setMovable(True)
