@@ -71,9 +71,9 @@ class TreeMessage(ToolbarWindow):
         @return
         """
 
-        self.refresh_act = QtGui.QAction(self.tr("&Refresh"), self)
+        self.refresh_act = QtGui.QAction(self)
         #self.refresh_act.setStatusTip(self.tr("Refresh"))
-        self.refresh_act.setIcon(QtGui.QIcon("../data/refresh.png"))
+        self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
         self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
                      self.reload_window)
 
