@@ -137,9 +137,9 @@ class ViewMessage(ToolbarWindow):
                     + '<h3><div class="title">%s</div></h3>' % (title)
                     + '<br/><div class="author">%s</div>' % (author)
                     + '<div class="date">%s</div>' % (date)
-                    + '<br/><div class="scribo_stl"> %s </div>' % (str(text))
+                    + '<br/><div class="scribo_stl"> %s </div>' % (unicode(text))
                     + '<br/><div class="tags">\
-                    %s</div></body>' % (str(tags)))
+                    %s</div></body>' % (unicode(tags)))
 
         del(title)
         del(text)
@@ -204,15 +204,15 @@ class ViewMessage(ToolbarWindow):
         self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
                      self.refresh_mes)
         """
-        self.up_act = QtGui.QAction(self.tr("&Previous"), self)
+        self.up_act = QtGui.QAction(self)
         #self.up_act.setStatusTip(self.tr("Previous message"))
-        self.up_act.setIcon(QtGui.QIcon("../data/prev.png"))
+        self.up_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_prev.png")))
         self.connect(self.up_act, QtCore.SIGNAL("triggered()"),
                      self.view_prev_message)
 
-        self.down_act = QtGui.QAction(self.tr("&Next"), self)
+        self.down_act = QtGui.QAction(self)
         #self.down_act.setStatusTip(self.tr("Next message"))
-        self.down_act.setIcon(QtGui.QIcon("../data/next.png"))
+        self.down_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_next.png")))
         self.connect(self.down_act, QtCore.SIGNAL("triggered()"),
                      self.view_next_message)
         #don't realized
@@ -223,15 +223,15 @@ class ViewMessage(ToolbarWindow):
         self.connect(self.comment_act, QtCore.SIGNAL("activated()"),
                      self.write_comment)
         """
-        self.edit_act = QtGui.QAction(self.tr("&Edit"), self)
+        self.edit_act = QtGui.QAction(self)
         #self.edit_act.setStatusTip(self.tr("Edit"))
-        self.edit_act.setIcon(QtGui.QIcon("../data/add_post.png"))
+        self.edit_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_edit.png")))
         self.connect(self.edit_act, QtCore.SIGNAL("triggered()"),
                      self.edit_post)
 
         self.tree_act = QtGui.QAction(self.tr("&Tree comments"), self)
         #self.tree_act.setStatusTip(self.tr("Tree of comments"))
-        self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
+        #self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
         self.connect(self.tree_act, QtCore.SIGNAL("triggered()"),
                      self.tree_comments)
 
